@@ -16,15 +16,7 @@ static PyMethodDef mod_methods[] = {
 
 /* Python glue */
 static struct PyModuleDef mod_module = {
-     PyModuleDef_HEAD_INIT,
-     "_StoreKit",
-     NULL,
-     0,
-     mod_methods,
-     NULL,
-     NULL,
-     NULL,
-     NULL};
+    PyModuleDef_HEAD_INIT, "_StoreKit", NULL, 0, mod_methods, NULL, NULL, NULL, NULL};
 
 PyObject* PyInit__StoreKit(void);
 
@@ -32,7 +24,9 @@ PyObject* __attribute__((__visibility__("default"))) PyInit__StoreKit(void)
 {
     PyObject* m;
     m = PyModule_Create(&mod_module);
-    if (!m) { return NULL; }
+    if (!m) {
+        return NULL;
+    }
 
     if (PyObjC_ImportAPI(m) == -1)
         return NULL;
